.. include:: ../README.rst
   :end-before: Installation and usage

.. toctree::
   :maxdepth: 3
   :caption: Contents:


   setup
   philosophy
   command_line
   processing_config
   examples
   glossary

.. toctree::
   :maxdepth: 1
   :caption: Code reference
   :glob:

   api/*


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
